@@ -36,6 +36,9 @@ def test_parse_primorial_standard_form():
         # two component primorial d
         ("5 * 11# / (3# * 7) - 13", (5, 11, 2*3*7, -13)),
         ("5 * 11# / (2# * 5) - 13", (5, 11, 10, -13)),
+        # no d
+        ("5 * 11# - 13", (5, 11, 1, -13)),
+        ("7 * 13# + 17", (7, 13, 1, 17)),
         # no m
         ("11# / 5 - 13", (1, 11, 5, -13)),
         ("11# / 5 + 17", (1, 11, 5, 17)),
